@@ -2,7 +2,7 @@
 # device.py
 # Python bindings for libparted (built on top of the _ped Python module).
 #
-# Copyright (C) 2009  Red Hat, Inc.
+# Copyright (C) 2009-2013 Red Hat, Inc.
 #
 # This copyrighted material is made available to anyone wishing to use,
 # modify, copy, or redistribute it subject to the terms and conditions of
@@ -18,7 +18,8 @@
 # License and may only be used or replicated with the express permission of
 # Red Hat, Inc.
 #
-# Red Hat Author(s): David Cantrell <dcantrell@redhat.com>
+# Author(s): David Cantrell <dcantrell@redhat.com>
+#            Alex Skinner <alex@lx.lc>
 #
 
 import math
@@ -26,9 +27,9 @@ import warnings
 
 import _ped
 import parted
-from disk import diskType
+from .disk import diskType
 
-from decorators import localeC
+from .decorators import localeC
 
 class Device(object):
     """Device()
@@ -53,7 +54,7 @@ class Device(object):
         elif path is not None:
             self.__device = _ped.device_get(path)
         else:
-            raise parted.DeviceException, "no path or PedDevice specified"
+            raise parted.DeviceException("no path or PedDevice specified")
 
     def __eq__(self, other):
         return not self.__ne__(other)
@@ -293,7 +294,7 @@ class Device(object):
         lunit = unit.lower()
 
         if lunit not in parted._exponent.keys():
-            raise SyntaxError, "invalid unit %s given" % (unit,)
+            raise SyntaxError("invalid unit %s given" % (unit))
 
         size = float(self.__device.length)
         size /= math.pow(1024.0, parted._exponent[lunit])
