@@ -2,7 +2,7 @@
 # disk.py
 # Python bindings for libparted (built on top of the _ped Python module).
 #
-# Copyright (C) 2009  Red Hat, Inc.
+# Copyright (C) 2009-2013 Red Hat, Inc.
 #
 # This copyrighted material is made available to anyone wishing to use,
 # modify, copy, or redistribute it subject to the terms and conditions of
@@ -18,14 +18,15 @@
 # License and may only be used or replicated with the express permission of
 # Red Hat, Inc.
 #
-# Red Hat Author(s): David Cantrell <dcantrell@redhat.com>
+# Author(s): David Cantrell <dcantrell@redhat.com>
+#            Alex Skinner <alex@lx.lc>
 #
 
 import _ped
 import parted
 
-from cachedlist import CachedList
-from decorators import localeC
+from .cachedlist import CachedList
+from .decorators import localeC
 
 class Disk(object):
     """Disk()
@@ -46,7 +47,7 @@ class Disk(object):
             else:
                 self._device = device
         elif device is None:
-            raise parted.DiskException, "no device specified"
+            raise parted.DiskException("no device specified")
         else:
             self.__disk = _ped.Disk(device.getPedDevice())
             self._device = device
@@ -245,7 +246,7 @@ class Disk(object):
             result = self.__disk.add_partition(partition.getPedPartition(),
                                                constraint.getPedConstraint())
         elif not partition:
-            raise parted.DiskException, "no partition or constraint specified"
+            raise parted.DiskException("no partition or constraint specified")
         else:
             result = self.__disk.add_partition(partition.getPedPartition())
 
@@ -264,7 +265,7 @@ class Disk(object):
            actually destroyed unless you use the deletePartition()
            method."""
         if not partition:
-            raise parted.DiskException, "no partition specified"
+            raise parted.DiskException("no partition specified")
 
         if self.__disk.remove_partition(partition.getPedPartition()):
             self.partitions.invalidate()
@@ -299,10 +300,10 @@ class Disk(object):
            does not modify the partition contents, just the partition
            table."""
         if not partition or not constraint:
-            raise parted.DiskException, "no partition or constraint specified"
+            raise parted.DiskException("no partition or constraint specified")
 
         if not start or not end:
-            raise parted.DiskException, "no start or end geometry specified"
+            raise parted.DiskException("no start or end geometry specified")
 
         return self.__disk.set_partition_geom(partition.getPedPartition(),
                                               constraint.getPedConstraint(),
@@ -313,7 +314,7 @@ class Disk(object):
         """Grow the Partition's Geometry to the maximum possible subject
            to Constraint."""
         if not partition:
-            raise parted.DiskException, "no partition specified"
+            raise parted.DiskException("no partition specified")
 
         if constraint:
             return self.__disk.maximize_partition(partition.getPedPartition(),
@@ -326,7 +327,7 @@ class Disk(object):
         """Get the maximum Geometry the Partition can be grown to,
            subject to the given Constraint."""
         if not partition:
-            raise parted.DiskException, "no partition specified"
+            raise parted.DiskException("no partition specified")
 
         if constraint:
             return parted.Geometry(PedGeometry=self.__disk.get_max_partition_geometry(partition.getPedPartition(), constraint.getPedConstraint()))
